==> ide-impl-193.5233.102-sources.jar: com/intellij/openapi/wm/impl/status/ShowProcessWindowAction.java <==
// Copyright 2000-2019 JetBrains s.r.o. Use of this source code is governed by the Apache 2.0 license that can be found in the LICENSE file.
package com.intellij.openapi.wm.impl.status;

import com.intellij.idea.ActionsBundle;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.actionSystem.ToggleAction;
import com.intellij.openapi.project.DumbAware;
import com.intellij.openapi.wm.ex.StatusBarEx;
import com.intellij.openapi.wm.impl.ProjectFrameHelper;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.awt.*;

final class ShowProcessWindowAction extends ToggleAction implements DumbAware {
  ShowProcessWindowAction() {
    super(ActionsBundle.message("action.ShowProcessWindow.text"), ActionsBundle.message("action.ShowProcessWindow.description"), null);
  }

  @Override
  public boolean isSelected(@NotNull AnActionEvent e) {
    ProjectFrameHelper frame = getFrame();
    if (frame != null) {
      StatusBarEx statusBar = frame.getStatusBar();
      if (statusBar != null) {
        return statusBar.isProcessWindowOpen();
      }
    }

    return false;
  }

  @Override
  public void update(@NotNull AnActionEvent e) {
    super.update(e);
    e.getPresentation().setEnabled(getFrame() != null);
  }

  @Override
  public void setSelected(@NotNull AnActionEvent e, boolean state) {
    ProjectFrameHelper frame = getFrame();
    if (frame != null) {
      StatusBarEx statusBar = frame.getStatusBar();
      if (statusBar != null) {
        statusBar.setProcessWindowOpen(state);
      }
    }
  }

  @Nullable
  private static ProjectFrameHelper getFrame() {
    return ProjectFrameHelper.getFrameHelper(KeyboardFocusManager.getCurrentKeyboardFocusManager().getFocusedWindow());
  }
}

==> ide-impl-202.6397.98-sources.jar: com/intellij/openapi/wm/impl/status/ShowProcessWindowAction.java <==
// Copyright 2000-2019 JetBrains s.r.o. Use of this source code is governed by the Apache 2.0 license that can be found in the LICENSE file.
package com.intellij.openapi.wm.impl.status;

import com.intellij.idea.ActionsBundle;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.actionSystem.ToggleAction;
import com.intellij.openapi.project.DumbAware;
import com.intellij.openapi.wm.ex.StatusBarEx;
import com.intellij.openapi.wm.impl.ProjectFrameHelper;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.awt.*;

final class ShowProcessWindowAction extends ToggleAction implements DumbAware {
  ShowProcessWindowAction() {
    super(ActionsBundle.messagePointer("action.ShowProcessWindow.text"), ActionsBundle.messagePointer("action.ShowProcessWindow.description"),
          null);
  }

  @Override
  public boolean isSelected(@NotNull AnActionEvent e) {
    ProjectFrameHelper frame = getFrame();
    if (frame != null) {
      StatusBarEx statusBar = frame.getStatusBar();
      if (statusBar != null) {
        return statusBar.isProcessWindowOpen();
      }
    }

    return false;
  }

  @Override
  public void update(@NotNull AnActionEvent e) {
    super.update(e);
    e.getPresentation().setEnabled(getFrame() != null);
  }

  @Override
  public void setSelected(@NotNull AnActionEvent e, boolean state) {
    ProjectFrameHelper frame = getFrame();
    if (frame != null) {
      StatusBarEx statusBar = frame.getStatusBar();
      if (statusBar != null) {
        statusBar.setProcessWindowOpen(state);
      }
    }
  }

  @Nullable
  private static ProjectFrameHelper getFrame() {
    return ProjectFrameHelper.getFrameHelper(KeyboardFocusManager.getCurrentKeyboardFocusManager().getFocusedWindow());
  }
}
